==> trip-0.1.0.tar.gz: trip-0.1.0/util/VSemaphore.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */





static const char* const VSemaphore_cxx_Version =
    "$Id: VSemaphore.cxx,v 1.7 2000/10/02 17:55:40 veer Exp $";
#include "VSemaphore.hxx"
#if defined(__svr4__)|| defined (__SUNPRO_CC)

#include <synch.h>

VSemaphore::VSemaphore(void)
{

    sema_init(&semaphore, 1, USYNC_THREAD, 0);

}

VSemaphore::VSemaphore(int available)
{

    sema_init(&semaphore, available, USYNC_THREAD, 0);
}

VSemaphore:: ~VSemaphore(void)
{
    sema_destroy(&semaphore);
}

void
VSemaphore::Post(void)
{
    sema_post(&semaphore);
}

void
VSemaphore::Post(int how_many)
{
    while (how_many-- > 0)
        sema_post(&semaphore);
}

void
VSemaphore::Wait(void)
{
    sema_wait(&semaphore);
}
#else

VSemaphore::VSemaphore(void)
{

    sem_init(&semaphore, 0, 1);

}

VSemaphore::VSemaphore(int available)
{

    sem_init(&semaphore, available, 1);
}

VSemaphore:: ~VSemaphore(void)
{
    sem_destroy(&semaphore);
}

void
VSemaphore::Post(void)
{
    sem_post(&semaphore);
}

void
VSemaphore::Post(int how_many)
{
    while (how_many-- > 0)
        sem_post(&semaphore);
}

void
VSemaphore::Wait(void)
{
    sem_wait(&semaphore);
}

#endif

==> trip-1.0.0.tar.gz: trip-1.0.0/util/VSemaphore.cxx <==
/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */

static const char* const VSemaphore_cxx_version =
    "$Id: VSemaphore.cxx,v 1.9 2001/01/23 22:40:55 bko Exp $";

#include "VSemaphore.hxx"

#if defined(__svr4__)|| defined (__SUNPRO_CC)

VSemaphore::VSemaphore(void)
{

    sema_init(&semaphore, 1, USYNC_THREAD, 0);

}

VSemaphore::VSemaphore(int available)
{

    sema_init(&semaphore, available, USYNC_THREAD, 0);
}

VSemaphore:: ~VSemaphore(void)
{
    sema_destroy(&semaphore);
}

void
VSemaphore::Post(void)
{
    sema_post(&semaphore);
}

void
VSemaphore::Post(int how_many)
{
    while (how_many-- > 0)
        sema_post(&semaphore);
}

void
VSemaphore::Wait(void)
{
    sema_wait(&semaphore);
}
#else

VSemaphore::VSemaphore(void)
{

    sem_init(&semaphore, 0, 1);

}

VSemaphore::VSemaphore(int available)
{

    sem_init(&semaphore, available, 1);
}

VSemaphore:: ~VSemaphore(void)
{
    sem_destroy(&semaphore);
}

void
VSemaphore::Post(void)
{
    sem_post(&semaphore);
}

void
VSemaphore::Post(int how_many)
{
    while (how_many-- > 0)
        sem_post(&semaphore);
}

void
VSemaphore::Wait(void)
{
    sem_wait(&semaphore);
}

#endif
